@@ -4,7 +4,6 @@
 from bits.google.services.base import Base
 from googleapiclient.discovery import build
 from google.cloud.billing.budgets import BudgetServiceClient
-from google.protobuf import json_format
 
 
 class CloudBillingBudgets(Base):
@@ -13,10 +12,10 @@ class CloudBillingBudgets(Base):
     def __init__(self, credentials):
         """Initialize a class instance."""
         self.budgets = build('billingbudgets', 'v1beta1', credentials=credentials, cache_discovery=False)
-        self.api_version = 'v1alpha1'
         self.credentials = credentials
         self.client = BudgetServiceClient()
 
+    # auto-discovery client
     def create_budget(self, parent, body):
         """Create a budget in the given billing account."""
         if 'billingAccounts/' not in parent:
@@ -53,15 +52,6 @@ class CloudBillingBudgets(Base):
         request = budgets.list(parent=parent)
         return self.get_list_items(budgets, request, 'budgets')
 
-    def list_budgets(self, parent):
-        """Return a list of budgets for the given billing account via the client."""
-        if 'billingAccounts/' not in parent:
-            parent = 'billingAccounts/{}'.format(parent)
-        budgets = []
-        for budget in self.client.list_budgets(parent=parent):
-            budgets.append(json_format.MessageToDict(budget))
-        return budgets
-
     def update_budget(self, parent, budget_id, body):
         """Update a budget in the given billing account."""
         if 'billingAccounts/' not in parent:
