@@ -11,7 +11,7 @@ class CloudSearch(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.cloudsearch = build('cloudsearch', 'v1', credentials=credentials)
+        self.cloudsearch = build('cloudsearch', 'v1', credentials=credentials, cache_discovery=False)
 
     def get_stats(self, params):
         """Return stats."""
