@@ -10,7 +10,7 @@ class Recommender(Base):
 
     def __init__(self, credentials):
         """Initialize a class instance."""
-        self.api_version = 'v1alpha1'
+        self.api_version = 'v1alpha2'
         self.base_url = 'https://recommender.googleapis.com/%s' % (
             self.api_version,
         )
@@ -50,5 +50,5 @@ class Recommender(Base):
 
     def get_role_recommendations(self, resource):
         """Return role recommendations for a resource."""
-        recommender = 'google.iam.policy.RoleRecommender'
+        recommender = 'google.iam.policy.Recommender'
         return self.get_recommendations(resource, 'global', recommender)
