@@ -4,7 +4,7 @@
 import base64
 
 from bits.google.services.base import Base
-from google.cloud import secretmanager_v1beta1
+from google.cloud import secretmanager_v1
 from google.protobuf import json_format
 from googleapiclient.discovery import build
 
@@ -16,11 +16,11 @@ class SecretManager(Base):
         """Initialize a class instance."""
         # google-python-api-client
         self.credentials = credentials
-        self.sm = build('secretmanager', 'v1beta1', credentials=credentials, cache_discovery=False)
+        self.sm = build('secretmanager', 'v1', credentials=credentials, cache_discovery=False)
 
         # google-cloud-secret-manager
-        self.secretmanager_v1beta1 = secretmanager_v1beta1
-        self.client = secretmanager_v1beta1.SecretManagerServiceClient()
+        self.secretmanager_v1 = secretmanager_v1
+        self.client = secretmanager_v1.SecretManagerServiceClient()
         self.json_format = json_format
 
     #
