@@ -17,7 +17,8 @@ class Sheets(Base):
             'sheets',
             'v4',
             credentials=credentials,
-            discoveryServiceUrl=discoveryUrl
+            discoveryServiceUrl=discoveryUrl,
+            cache_discovery=False,
         )
 
     def batchupdate_sheet(self, spreadsheetId, body=[]):
